@@ -13,12 +13,13 @@ DBUS_SINK_PREFIX = "com.wirepas.sink."
 
 
 class Sink:
-    def __init__(self, bus, proxy, sink_id, unique_name, on_stack_started, logger=None):
+    def __init__(self, bus, proxy, sink_id, unique_name, on_stack_started, on_stack_stopped, logger=None):
 
         self.proxy = proxy
         self.sink_id = sink_id
         self.network_address = None
         self.on_stack_started = on_stack_started
+        self.on_stack_stopped = on_stack_stopped
         self.bus = bus
         self.unique_name = unique_name
         self.on_started_handle = None
@@ -39,13 +40,23 @@ class Sink:
         if self.on_started_handle is not None:
             self.on_started_handle.unsubscribe()
 
+    def register_for_stack_stopped(self):
+        # Use the subscribe directly to be able to specify the sender
+        self.on_started_handle = self.bus.subscribe(
+            signal="StackStopped",
+            object="/com/wirepas/sink",
+            iface="com.wirepas.sink.config1",
+            sender=self.unique_name,
+            signal_fired=self._on_stack_stopped,
+        )
+
     def get_network_address(self, force=False):
         if self.network_address is None or force:
             # Network address is not known or must be updated
             try:
                 self.network_address = self.proxy.NetworkAddress
             except GLib.Error:
-                self.logger.exception("Could not get network address")
+                self.logger.error("Could not get network address")
 
         return self.network_address
 
@@ -92,16 +103,20 @@ class Sink:
 
         self.on_stack_started(self.sink_id)
 
+    def _on_stack_stopped(self, sender, object, iface, signal, params):
+        self.on_stack_stopped(self.sink_id)
+
     def _get_param(self, dic, key, attribute):
         try:
             dic[key] = getattr(self.proxy, attribute)
-        except (GLib.Error, AttributeError):
-            # Exception raised when getting attribute (probably not set)
-            # Discard channel_map as parameter present only for old stacks
+        except  GLib.Error:
             if key != "channel_map":
                 # Warning and not an error as normal behavior if not set
                 self.logger.warning("Cannot get %s in config (is it set?)", key)
 
+        except AttributeError :
+            self.logger.warning("Attribute %s doesn't exist", key)
+
     def _get_pair_params(self, dic, key1, att1, key2, att2):
         # Some settings are only relevant if the both can be retrieved
         try:
@@ -264,7 +279,7 @@ class Sink:
                 )
                 self.proxy.SetStackState(new_state)
         except GLib.Error as err:
-            res = ReturnCode.error_from_dbus_exception(err.message)
+            res = ReturnCode.error_from_dbus_exception(str(err))
             self.logger.exception(
                 "Cannot set Stack state. Problem in communication probably: %s",
                 res.name,
@@ -293,8 +308,13 @@ class Sink:
 
         try:
             self.proxy.SinkCost = new_cost
-        except GLib.Error:
-            self.logger.error("Cannot set sink cost for sink {}".format(self.sink_id))
+        except GLib.Error as err:
+            res = ReturnCode.error_from_dbus_exception(err.message)
+            if res == wmm.GatewayResultCode.GW_RES_INVALID_ROLE:
+                self.logger.warning("Node role is not a sink, sink cost cannot be modified")
+                raise ValueError("Wrong role to set cost value {}".format(new_cost))
+            else:
+                self.logger.error("Cannot set sink cost for sink {} ({})".format(self.sink_id, res))
 
     def get_scratchpad_status(self):
         d = {}
@@ -482,7 +502,7 @@ class SinkManager:
     "Helper class to manage the Sink list"
 
     def __init__(
-        self, bus, on_new_sink_cb, on_sink_removal_cb, on_stack_started, logger=None
+        self, bus, on_new_sink_cb, on_sink_removal_cb, on_stack_started, on_stack_stopped, logger=None
     ):
 
         self.logger = logger or logging.getLogger(__name__)
@@ -494,6 +514,7 @@ class SinkManager:
         self.add_cb = None
         self.rm_cb = None
         self.stack_started_cb = on_stack_started
+        self.stack_stopped_cb = on_stack_stopped
 
         bus_monitor = self.bus.get("org.freedesktop.DBus")
 
@@ -531,10 +552,12 @@ class SinkManager:
             sink_id=short_name,
             unique_name=unique_name,
             on_stack_started=self.stack_started_cb,
+            on_stack_stopped=self.stack_stopped_cb,
             logger=self.logger,
         )
 
         sink.register_for_stack_started()
+        sink.register_for_stack_stopped()
 
         self.sinks[short_name] = sink
 
