@@ -90,12 +90,8 @@ class ConnectionToBackendMonitorThread(Thread):
             # No max delay set, not enabled
             return False
 
-        if self.mqtt_wrapper.publish_queue_size <= 0:
-            # No packet queued, so nothing to check
-            return False
-
         return (
-            self.mqtt_wrapper.last_published_packet_s > self.max_delay_without_publish
+            self.mqtt_wrapper.publish_waiting_time_s > self.max_delay_without_publish
         )
 
     def _is_buffer_threshold_reached(self):
@@ -123,7 +119,7 @@ class ConnectionToBackendMonitorThread(Thread):
                     self.logger.info("Increasing sink cost of all sinks")
                     self.logger.debug(
                         "Last publish: %s Queue Size %s",
-                        self.mqtt_wrapper.last_published_packet_s,
+                        self.mqtt_wrapper.publish_waiting_time_s,
                         self.mqtt_wrapper.publish_queue_size,
                     )
 
@@ -294,6 +290,15 @@ class TransportService(BusClient):
             topic, self._on_otap_set_target_scratchpad_request_received
         )
 
+        # Register ourself to our status in case someone else (by mistake)
+        # update our status.
+        # It will work only if we are allowed to register for event topic
+        # at broker level
+        topic = TopicGenerator.make_status_topic(self.gw_id)
+        self.mqtt_wrapper.subscribe(
+            topic, self._on_own_status_received
+        )
+
         self._set_status()
 
         self.logger.info("MQTT connected!")
@@ -364,12 +369,20 @@ class TransportService(BusClient):
         self.mqtt_wrapper.publish(topic, event.payload, qos=1)
 
     def on_stack_started(self, name):
+        self.logger.debug("Sink started: %s", name)
+        # Generate a setconfig answer with req_id of 0
+        self. _send_asynchronous_set_config_response(name)
+
+    def on_stack_stopped(self, name):
+        self.logger.debug("Sink stopped: %s", name)
+        # Generate a setconfig answer with req_id of 0
+        self. _send_asynchronous_set_config_response(name)
+
+    def _send_asynchronous_set_config_response(self, name):
         sink = self.sink_manager.get_sink(name)
         if sink is None:
-            self.logger.error("Sink started %s error: unknown sink", name)
+            self.logger.error("Sink %s error: unknown sink", name)
             return
-
-        # Generate a setconfig answer with req_id of 0
         response = wmm.SetConfigResponse(
             0,
             self.gw_id,
@@ -425,7 +438,10 @@ class TransportService(BusClient):
                         name, self.minimum_sink_cost
                     )
                 )
-                sink.cost = self.minimum_sink_cost
+                try:
+                    sink.cost = self.minimum_sink_cost
+                except ValueError:
+                    self.logger.debug("Cannot set cost, probably not a sink")
 
         self._send_asynchronous_get_configs_response()
 
@@ -497,6 +513,23 @@ class TransportService(BusClient):
 
         self.mqtt_wrapper.publish(topic, response.payload, qos=2)
 
+    @deferred_thread
+    def _on_own_status_received(self, client, userdata, message):
+        try:
+            if message.payload.__len__() > 0:
+                request = wmm.StatusEvent.from_payload(message.payload)
+                if request.state == wmm.GatewayState.ONLINE:
+                    # Everything is fine, this is our state
+                    return
+        except wmm.GatewayAPIParsingException:
+            pass
+
+        # If we are here, something happened to our status.
+        # Either not online or malformed or empty
+        self.logger.error("Gateway info request is wrong or updated")
+        # Set our status back
+        self._set_status()
+
     def _on_get_gateway_info_cmd_received(self, client, userdata, message):
         # pylint: disable=unused-argument
         """
